/*
 * inlines.h
 * Contains inlinable fuctions for renum
 *
 * Copyright 2004-2005 by Dale McCoy.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef _RENUM_INLINES_H_INCLUDED_
#define _RENUM_INLINES_H_INCLUDED_

#include<iostream>
#include<cstdarg>
#include<cassert>

#include"globals.h"
#include"renum.h"
#include"messages.h"
#include"command.h"

inline istream&eat_white(istream&in){
	while(isspace(in.peek()))in.ignore();
	return in;
}

inline int ctoi(char ch){
	if(ch>='0'&&ch<='9')return ch-'0';
	if(ch>='A'&&ch<='F')return ch-'A'+10;
	if(ch>='a'&&ch<='f')return ch-'a'+10;
	return 0;
}

inline bool is_comment(const string&line){
	return line==""||COMMENT.find(line[line.find_first_not_of(WHITESPACE)])!=NPOS;
}

inline string UCase(string str){
	size_t len=str.length();
	for(size_t i=0;i<len;i++)
		str[i]=(char)toupper(str[i]);
	return str;
}

inline string itoa(unsigned int x,int radix=10,uint minlen=1){
	string ret;
	if(!x)ret="0";
	int temp;
	while(x){
		temp=x%radix;
		ret=(char)(temp<10?'0'+temp:'7'/*'A'-10*/+temp)+ret;
		x/=radix;
	}
	while(ret.length()<minlen)
		ret=((radix==10)?" ":"0")+ret;
	return ret;
}

inline string itoa(int x,int radix=10,uint minlen=1){
	if(x>=0)return itoa((uint)x,radix,minlen);
	if(x==INT_MIN)return "-"+itoa(uint(INT_MAX)+1,radix,minlen);
	else return "-"+itoa((uint)-x,radix,minlen);
}

#endif//_RENUM_INLINES_H_INCLUDED_
